'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

// The theme file is based on the specification at https://system-ui.com/theme
// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue

var colors = {
  reds: ["#660505", //news-100
  "#8B0000", //news-200
  "#AB0613", //news-300
  "#C70000", //news-400
  "#FF5943", //news-500
  "#FFBAC8", //news-600
  "#FFF4F2" //news-800
  ],
  oranges: ["#672005", //opinion-100
  "#8D2700", //opinion-200
  "#BD5318", //opinion-300
  "#E05E00", //opinion-400
  "#FF7F0F", //opinion-500
  "#F9B376", //opinion-600
  "#FEF9F5" //opinion-800
  ],
  blues: ["#003C60", //sport-100
  "#004E7C", //sport-200
  "#005689", //sport-300
  "#0084C6", //sport-400
  "#00B2FF", //sport-500
  "#90DCFF", //sport-600
  "#F1F8FC", //sport-800
  "#001536", //brand-100
  "#041F4A", //brand-300
  "#052962", //brand-400
  "#007ABC", //brand-500
  "#506991", //brand-600
  "#C1D8FC" //brand-800
  ],
  browns: ["#3E3323", //culture-100
  "#574835", //culture-200
  "#6B5840", //culture-300
  "#A1845C", //culture-400
  "#EACCA0", //culture-500
  "#E7D4B9", //culture-600
  "#FBF6EF" //culture-800
  ],
  pinks: ["#510043", //lifestyle-100
  "#650054", //lifestyle-200
  "#7D0068", //lifestyle-300
  "#BB3B80", //lifestyle-400
  "#FFABDB", //lifestyle-500
  "#FEC8D3", //lifestyle-600
  "#FEEEF7" //lifestyle-800
  ],
  yellows: ["#F3C100", //brandAlt-200
  "#FFD900", //brandAlt-300
  "#FFE500" //brandAlt-400
  ],
  greens: ["#185E36", //green-200
  "#22874D", //green-400
  "#4B8878", //labs-200
  "#65A897", //labs-300
  "#69D1CA" //labs-400
  ],
  grays: ["#000000", //neutral-0
  "#121212", //neutral-7
  "#1A1A1A", //neutral-10
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF", //neutral-100
  "#222527", //specialReport-100
  "#303538", //specialReport-200
  "#3F464A", //specialReport-300
  "#63717A", //specialReport-400
  "#ABC2C9", //specialReport-500
  "#33393D" //dynamo-400
  ]
};

// Global colour names that correspond to https://www.theguardian.design/2a1e5182b/p/938810-colour/b/587ef3
var brand = {
  100: colors.blues[7],
  300: colors.blues[8],
  400: colors.blues[9],
  500: colors.blues[10],
  600: colors.blues[11],
  800: colors.blues[12],
  // legacy names: please do not use
  dark: colors.blues[8],
  main: colors.blues[9],
  bright: colors.blues[10],
  pastel: colors.blues[11],
  faded: colors.blues[12]
};
var brandAlt = {
  200: colors.yellows[0],
  300: colors.yellows[0],
  // TODO: update to colors.yellow[1] (#FFD900)
  400: colors.yellows[2],
  // legacy names: please do not use
  dark: colors.yellows[0],
  // TODO: update to colors.yellow[1] (#FFD900)
  main: colors.yellows[2]
}; // continue to expose legacy name for compatibility
var neutral = {
  0: colors.grays[0],
  7: colors.grays[1],
  10: colors.grays[2],
  20: colors.grays[3],
  46: colors.grays[4],
  60: colors.grays[5],
  86: colors.grays[6],
  93: colors.grays[7],
  97: colors.grays[8],
  100: colors.grays[9]
};
var error = {
  400: colors.reds[3],
  500: colors.reds[4],
  // legacy names: please do not use
  main: colors.reds[3],
  bright: colors.reds[4]
};
var success = {
  400: colors.greens[1],
  // legacy names: please do not use
  main: colors.greens[1]
};
var sport = {
  100: colors.blues[0],
  200: colors.blues[1],
  300: colors.blues[2],
  400: colors.blues[3],
  500: colors.blues[4],
  600: colors.blues[5],
  800: colors.blues[6],
  // legacy names: please do not use
  dark: colors.blues[2],
  main: colors.blues[3],
  bright: colors.blues[4],
  pastel: colors.blues[5],
  faded: colors.blues[6]
};

var primary = neutral[100];
var inverse = neutral[10];
var checkableChecked = brand[500];
var ctaPrimary = brand[400];
var ctaPrimaryHover = "#234B8A";
var ctaSecondary = brand[800];
var ctaSecondaryHover = "#ACC9F7";
var root = {
  primary: primary,
  inverse: inverse,
  checkableChecked: checkableChecked,
  ctaPrimary: ctaPrimary,
  ctaPrimaryHover: ctaPrimaryHover,
  ctaSecondary: ctaSecondary,
  ctaSecondaryHover: ctaSecondaryHover
};
var button = {
  buttonPrimary: ctaPrimary,
  buttonPrimaryHover: ctaPrimaryHover,
  buttonSecondary: ctaSecondary,
  buttonSecondaryHover: ctaSecondaryHover
};
var checkbox = {
  checkboxChecked: checkableChecked
};
var radio = {
  radioChecked: checkableChecked
};
var textInput = {
  textInput: primary
};
var background = _objectSpread2({}, root, {}, button, {}, checkbox, {}, radio, {}, textInput);

var primary$1 = brand[400];
var checkableChecked$1 = neutral[100];
var ctaPrimary$1 = neutral[100];
var ctaPrimaryHover$1 = "#E0E0E0";
var ctaSecondary$1 = brand[600];
var ctaSecondaryHover$1 = "#234B8A";
var root$1 = {
  primary: primary$1,
  checkableChecked: checkableChecked$1,
  ctaPrimary: ctaPrimary$1,
  ctaPrimaryHover: ctaPrimaryHover$1,
  ctaSecondary: ctaSecondary$1,
  ctaSecondaryHover: ctaSecondaryHover$1
};
var button$1 = {
  buttonPrimary: ctaPrimary$1,
  buttonPrimaryHover: ctaPrimaryHover$1,
  buttonSecondary: ctaSecondary$1,
  buttonSecondaryHover: ctaSecondaryHover$1
};
var checkbox$1 = {
  checkboxChecked: checkableChecked$1
};
var radio$1 = {
  radioChecked: checkableChecked$1
};
var brandBackground = _objectSpread2({}, root$1, {}, button$1, {}, checkbox$1, {}, radio$1);

var primary$2 = brandAlt[400];
var ctaPrimary$2 = neutral[7];
var ctaPrimaryHover$2 = "#454545";
var ctaSecondary$2 = brandAlt[200];
var ctaSecondaryHover$2 = "#F2AE00";
var root$2 = {
  primary: primary$2,
  ctaPrimary: ctaPrimary$2,
  ctaPrimaryHover: ctaPrimaryHover$2,
  ctaSecondary: ctaSecondary$2,
  ctaSecondaryHover: ctaSecondaryHover$2
};
var button$2 = {
  buttonPrimary: ctaPrimary$2,
  buttonPrimaryHover: ctaPrimaryHover$2,
  buttonSecondary: ctaSecondary$2,
  buttonSecondaryHover: ctaSecondaryHover$2
};
var brandAltBackground = _objectSpread2({}, root$2, {}, button$2);

var primary$3 = neutral[60];
var secondary = neutral[86];
var success$1 = success[400];
var error$1 = error[400];
var checkableChecked$2 = brand[500];
var checkableHover = brand[500];
var focusHalo = sport[500];
var root$3 = {
  primary: primary$3,
  secondary: secondary,
  success: success$1,
  error: error$1,
  checkableChecked: checkableChecked$2,
  checkableHover: checkableHover,
  focusHalo: focusHalo
};
var checkbox$2 = {
  checkbox: primary$3,
  checkboxHover: checkableHover,
  checkboxChecked: checkableChecked$2,
  checkboxError: error$1
};
var choiceCard = {
  choiceCard: primary$3,
  choiceCardHover: checkableHover,
  choiceCardChecked: checkableChecked$2
};
var radio$2 = {
  radio: primary$3,
  radioHover: checkableHover,
  radioError: error$1
};
var textInput$1 = {
  textInput: primary$3,
  textInputError: error$1
};
var border = _objectSpread2({}, root$3, {}, checkbox$2, {}, choiceCard, {}, radio$2, {}, textInput$1);

var primary$4 = brand[800];
var success$2 = success[400];
var error$2 = error[500];
var checkableChecked$3 = neutral[100];
var checkableHover$1 = neutral[100];
var root$4 = {
  primary: primary$4,
  success: success$2,
  error: error$2,
  checkableChecked: checkableChecked$3,
  checkableHover: checkableHover$1
};
var checkbox$3 = {
  checkbox: primary$4,
  checkboxHover: checkableHover$1,
  checkboxChecked: checkableChecked$3,
  checkboxError: error$2
};
var radio$3 = {
  radio: primary$4,
  radioHover: checkableHover$1,
  radioError: error$2
};
var brandBorder = _objectSpread2({}, root$4, {}, checkbox$3, {}, radio$3);

var primary$5 = neutral[86];
var root$5 = {
  primary: primary$5
};
var line = _objectSpread2({}, root$5);

var primary$6 = brand[600];
var root$6 = {
  primary: primary$6
};
var brandLine = _objectSpread2({}, root$6);

var primary$7 = neutral[7];
var root$7 = {
  primary: primary$7
};
var brandAltLine = _objectSpread2({}, root$7);

var primary$8 = neutral[7];
var secondary$1 = neutral[46]; //TODO: deprecate?

var supporting = neutral[46];
var success$3 = success[400];
var error$3 = error[400];
var ctaPrimary$3 = neutral[100];
var ctaSecondary$3 = brand[400];
var anchorPrimary = brand[500];
var anchorSecondary = neutral[7];
var root$8 = {
  primary: primary$8,
  secondary: secondary$1,
  supporting: supporting,
  success: success$3,
  error: error$3,
  ctaPrimary: ctaPrimary$3,
  ctaSecondary: ctaSecondary$3,
  anchorPrimary: anchorPrimary,
  anchorSecondary: anchorSecondary
};
var button$3 = {
  buttonPrimary: ctaPrimary$3,
  buttonSecondary: ctaSecondary$3
};
var checkbox$4 = {
  checkbox: primary$8,
  checkboxSupporting: supporting,
  checkboxIndeterminate: supporting
};
var choiceCard$1 = {
  choiceCard: supporting,
  choiceCardChecked: ctaSecondary$3,
  choiceCardHover: ctaSecondary$3
};
var link = {
  linkPrimary: anchorPrimary,
  linkPrimaryHover: anchorPrimary,
  linkSecondary: anchorSecondary,
  linkSecondaryHover: anchorSecondary
};
var radio$4 = {
  radio: primary$8,
  radioSupporting: supporting
};
var textInput$2 = {
  textInput: primary$8,
  textInputLabel: primary$8,
  textInputOptionalLabel: supporting,
  textInputSupporting: supporting,
  textInputError: error$3
};
var text = _objectSpread2({}, root$8, {}, button$3, {}, checkbox$4, {}, choiceCard$1, {}, link, {}, radio$4, {}, textInput$2);

var primary$9 = neutral[100];
var secondary$2 = brand[800]; //TODO: deprecate?

var supporting$1 = brand[800];
var success$4 = success[400];
var error$4 = error[500];
var ctaPrimary$4 = brand[400];
var ctaSecondary$4 = neutral[100];
var anchorPrimary$1 = neutral[100];
var root$9 = {
  primary: primary$9,
  secondary: secondary$2,
  supporting: supporting$1,
  success: success$4,
  error: error$4,
  ctaPrimary: ctaPrimary$4,
  ctaSecondary: ctaSecondary$4,
  anchorPrimary: anchorPrimary$1
};
var button$4 = {
  buttonPrimary: ctaPrimary$4,
  buttonSecondary: ctaSecondary$4
};
var checkbox$5 = {
  checkbox: primary$9,
  checkboxSupporting: supporting$1,
  checkboxIndeterminate: supporting$1
};
var link$1 = {
  linkPrimary: anchorPrimary$1,
  linkPrimaryHover: anchorPrimary$1
};
var radio$5 = {
  radio: primary$9,
  radioSupporting: supporting$1
};
var brandText = _objectSpread2({}, root$9, {}, button$4, {}, checkbox$5, {}, link$1, {}, radio$5);

var primary$a = neutral[7];
var secondary$3 = neutral[60]; //TODO: deprecate?

var supporting$2 = neutral[60];
var ctaPrimary$5 = neutral[100];
var ctaSecondary$5 = neutral[7];
var anchorPrimary$2 = neutral[7];
var root$a = {
  primary: primary$a,
  secondary: secondary$3,
  supporting: supporting$2,
  ctaPrimary: ctaPrimary$5,
  ctaSecondary: ctaSecondary$5,
  anchorPrimary: anchorPrimary$2
};
var button$5 = {
  buttonPrimary: ctaPrimary$5,
  buttonSecondary: ctaSecondary$5
};
var link$2 = {
  linkPrimary: anchorPrimary$2,
  linkPrimaryHover: anchorPrimary$2
};
var brandAltText = _objectSpread2({}, root$a, {}, button$5, {}, link$2);

var buttonDefault = {
  button: {
    textPrimary: text.buttonPrimary,
    backgroundPrimary: background.buttonPrimary,
    backgroundPrimaryHover: background.buttonPrimaryHover,
    textSecondary: text.buttonSecondary,
    backgroundSecondary: background.buttonSecondary,
    backgroundSecondaryHover: background.buttonSecondaryHover,
    textTertiary: text.buttonSecondary,
    backgroundTertiary: background.primary
  }
};
var buttonBrand = {
  button: {
    textPrimary: brandText.buttonPrimary,
    backgroundPrimary: brandBackground.buttonPrimary,
    backgroundPrimaryHover: brandBackground.buttonPrimaryHover,
    textSecondary: brandText.buttonSecondary,
    backgroundSecondary: brandBackground.buttonSecondary,
    backgroundSecondaryHover: brandBackground.buttonSecondaryHover,
    textTertiary: brandText.buttonSecondary,
    backgroundTertiary: brandBackground.primary
  }
};
var buttonBrandAlt = {
  button: {
    textPrimary: brandAltText.buttonPrimary,
    backgroundPrimary: brandAltBackground.buttonPrimary,
    backgroundPrimaryHover: brandAltBackground.buttonPrimaryHover,
    textSecondary: brandAltText.buttonSecondary,
    backgroundSecondary: brandAltBackground.buttonSecondary,
    backgroundSecondaryHover: brandAltBackground.buttonSecondaryHover,
    textTertiary: brandAltText.buttonSecondary,
    backgroundTertiary: brandAltBackground.primary
  }
}; // continue to expose legacy theme names

var buttonLight = buttonDefault;
var buttonBrandYellow = buttonBrandAlt;

var inlineErrorDefault = {
  inlineError: {
    text: text.error
  }
};
var inlineErrorBrand = {
  inlineError: {
    text: brandText.error
  }
}; // continue to expose legacy theme names

var inlineErrorLight = inlineErrorDefault;

var checkboxDefault = _objectSpread2({
  checkbox: {
    border: border.checkbox,
    borderHover: border.checkboxHover,
    borderChecked: border.checkboxChecked,
    borderError: border.checkboxError,
    backgroundChecked: background.checkboxChecked,
    text: text.checkbox,
    textSupporting: text.checkboxSupporting,
    textIndeterminate: text.checkboxIndeterminate
  }
}, inlineErrorDefault);
var checkboxBrand = _objectSpread2({
  checkbox: {
    border: brandBorder.checkbox,
    borderHover: brandBorder.checkboxHover,
    borderChecked: brandBorder.checkboxChecked,
    borderError: brandBorder.checkboxError,
    backgroundChecked: brandBackground.checkboxChecked,
    text: brandText.checkbox,
    textSupporting: brandText.checkboxSupporting,
    textIndeterminate: brandText.checkboxIndeterminate
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var checkboxLight = checkboxDefault;

var choiceCardDefault = _objectSpread2({
  choiceCard: {
    text: text.choiceCard,
    borderColor: border.choiceCard,
    textChecked: text.choiceCardChecked,
    backgroundChecked: "#E3F6FF",
    borderColorChecked: border.choiceCardChecked,
    textHover: text.choiceCardHover,
    borderColorHover: border.choiceCardHover
  }
}, inlineErrorDefault);

var linkDefault = {
  link: {
    textPrimary: text.linkPrimary,
    textPrimaryHover: text.linkPrimaryHover,
    textSecondary: text.linkSecondary,
    textSecondaryHover: text.linkSecondaryHover
  }
};
var linkBrand = {
  link: {
    textPrimary: brandText.linkPrimary,
    textPrimaryHover: brandText.linkPrimaryHover
  }
};
var linkBrandAlt = {
  link: {
    textPrimary: brandAltText.linkPrimary,
    textPrimaryHover: brandAltText.linkPrimaryHover
  }
}; // continue to expose legacy theme names

var linkLight = linkDefault;
var linkBrandYellow = linkBrandAlt;

var radioDefault = _objectSpread2({
  radio: {
    borderHover: border.radioHover,
    border: border.radio,
    backgroundChecked: background.radioChecked,
    text: text.radio,
    textSupporting: text.radioSupporting,
    borderError: border.radioError
  }
}, inlineErrorLight);
var radioBrand = _objectSpread2({
  radio: {
    borderHover: brandBorder.radioHover,
    border: brandBorder.radio,
    backgroundChecked: brandBackground.radioChecked,
    text: brandText.radio,
    textSupporting: brandText.radioSupporting,
    borderError: brandBorder.radioError
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var radioLight = radioDefault;

var textInputDefault = _objectSpread2({
  textInput: {
    textInput: text.textInput,
    textLabel: text.textInputLabel,
    textOptionalLabel: text.textInputOptionalLabel,
    textSupporting: text.textInputSupporting,
    textError: text.textInputError,
    backgroundInput: background.textInput,
    border: border.textInput,
    borderError: border.textInputError
  }
}, inlineErrorDefault); // continue to expose legacy theme names

var textInputLight = textInputDefault;

var defaultTheme = _objectSpread2({}, buttonDefault, {}, checkboxDefault, {}, choiceCardDefault, {}, inlineErrorDefault, {}, linkDefault, {}, radioDefault, {}, textInputDefault, {}, buttonLight, {}, checkboxLight, {}, inlineErrorLight, {}, linkLight, {}, radioLight, {}, textInputLight);
var brand$1 = _objectSpread2({}, buttonBrand, {}, checkboxBrand, {}, inlineErrorBrand, {}, linkBrand, {}, radioBrand);
var brandAlt$1 = _objectSpread2({}, buttonBrandAlt, {}, linkBrandAlt, {}, buttonBrandYellow, {}, linkBrandYellow); // continue to expose legacy theme names

var light = defaultTheme;
var brandYellow = brandAlt$1;

exports.brand = brand$1;
exports.brandAlt = brandAlt$1;
exports.brandYellow = brandYellow;
exports.buttonBrand = buttonBrand;
exports.buttonBrandAlt = buttonBrandAlt;
exports.buttonBrandYellow = buttonBrandYellow;
exports.buttonDefault = buttonDefault;
exports.buttonLight = buttonLight;
exports.checkboxBrand = checkboxBrand;
exports.checkboxDefault = checkboxDefault;
exports.checkboxLight = checkboxLight;
exports.choiceCardDefault = choiceCardDefault;
exports.defaultTheme = defaultTheme;
exports.inlineErrorBrand = inlineErrorBrand;
exports.inlineErrorDefault = inlineErrorDefault;
exports.inlineErrorLight = inlineErrorLight;
exports.light = light;
exports.linkBrand = linkBrand;
exports.linkBrandAlt = linkBrandAlt;
exports.linkBrandYellow = linkBrandYellow;
exports.linkDefault = linkDefault;
exports.linkLight = linkLight;
exports.radioBrand = radioBrand;
exports.radioDefault = radioDefault;
exports.radioLight = radioLight;
exports.textInputDefault = textInputDefault;
exports.textInputLight = textInputLight;
